Import-Module "$($pwd)\Microsoft.SharePoint.Client.dll"
Import-Module "$($pwd)\Microsoft.SharePoint.Client.Runtime.dll"

$site = ""

$username = ""
$password = ""
$useDefaultNetowrkCredentials = $true

if($useDefaultNetowrkCredentials -eq $true){
	$credentials = [System.Net.CredentialCache]::DefaultNetworkCredentials 
}
elseif($username -ne "" -and $password -ne ""){
	$securePassword = ConvertTo-SecureString $password -AsPlainText -Force 
	$credentials = New-Object Microsoft.SharePoint.Client.SharePointOnlineCredentials($username, $securePassword)
}

#Connect to Site Collection
$context = New-Object Microsoft.SharePoint.Client.ClientContext($site)
$context.Credentials = $credentials
if($context.ServerObjectIsNull.Value){
	Write-Warning "Not connected to SharePoint"
	return
}

#Check if PluginAttributes list is avialable or needs to be created
$listName = "AutoAttendant"
try{
	$list = $context.Web.Lists.GetByTitle($listName)
	$context.Load($list)
	$context.ExecuteQuery()

	if($list.Count -gt 0){
		Write-Host "List $($listName) already exists"
	}
}
catch{
	Write-Warning "List $($listName) does not exist yet, creating it now"
	#Create list
	$listinfo = New-Object Microsoft.SharePoint.Client.ListCreationInformation
	$listinfo.Title = $listName
	$listinfo.TemplateType = [Microsoft.SharePoint.Client.ListTemplateType]"GenericList"
	$list = $context.Web.Lists.Add($listinfo)
	$context.ExecuteQuery()
	
	#Check if list is available
	$list = $context.Web.Lists.GetByTitle($listName)
	$context.Load($list)
	$context.ExecuteQuery()

	if($list.Count -gt 0){
		#Add field
		$fieldXml = "<Field Type='Text' Name='sip' StaticName='sip' DisplayName='Sip Address' Required='TRUE' />"
		$field = $list.Fields.AddFieldAsXml($fieldXml, $true, [Microsoft.SharePoint.Client.AddFieldOptions]::AddFieldInternalNameHint) 
		$context.Load($field)
		
		#Add field
		$fieldXml = "<Field Type='Text' Name='column1' StaticName='column1' DisplayName='First Name' Required='TRUE' />"
		$field = $list.Fields.AddFieldAsXml($fieldXml, $true, [Microsoft.SharePoint.Client.AddFieldOptions]::AddFieldInternalNameHint) 
		$context.Load($field)
		
		#Add field
		$fieldXml = "<Field Type='Text' Name='filtercolumn1' StaticName='filtercolumn1' DisplayName='First Name (filter)' Decimals='0' Hidden='TRUE' />"
		$field = $list.Fields.AddFieldAsXml($fieldXml, $true, [Microsoft.SharePoint.Client.AddFieldOptions]::AddFieldInternalNameHint) 
		$context.Load($field)
		
		#Add field
		$fieldXml = "<Field Type='Text' Name='column2' StaticName='column2' DisplayName='Last Name' Required='TRUE' />"
		$field = $list.Fields.AddFieldAsXml($fieldXml, $true, [Microsoft.SharePoint.Client.AddFieldOptions]::AddFieldInternalNameHint) 
		$context.Load($field)
		
		#Add field
		$fieldXml = "<Field Type='Text' Name='filtercolumn2' StaticName='filtercolumn2' DisplayName='Last Name (filter)' Decimals='0' Hidden='TRUE' />"
		$field = $list.Fields.AddFieldAsXml($fieldXml, $true, [Microsoft.SharePoint.Client.AddFieldOptions]::AddFieldInternalNameHint) 
		$context.Load($field)
		
		#Add field
		$fieldXml = "<Field Type='Text' Name='column3' StaticName='column3' DisplayName='Department' Required='TRUE' />"
		$field = $list.Fields.AddFieldAsXml($fieldXml, $true, [Microsoft.SharePoint.Client.AddFieldOptions]::AddFieldInternalNameHint) 
		$context.Load($field)
		
		#Add field
		$fieldXml = "<Field Type='Text' Name='filtercolumn3' StaticName='filtercolumn3' DisplayName='Department (filter)' Decimals='0' Hidden='TRUE' />"
		$field = $list.Fields.AddFieldAsXml($fieldXml, $true, [Microsoft.SharePoint.Client.AddFieldOptions]::AddFieldInternalNameHint) 
		$context.Load($field)
		
		$context.ExecuteQuery()
		
		Write-Warning "List $($listName) is created successfully"
	}
}

$context.Dispose()